[rkward-cvs] SF.net SVN: rkward:[4029] trunk/rkward/rkward/rbackend/rkrbackend.cpp

tfry at users.sourceforge.net tfry at users.sourceforge.net
Sun Nov 13 12:11:10 UTC 2011


Revision: 4029
          http://rkward.svn.sourceforge.net/rkward/?rev=4029&view=rev
Author:   tfry
Date:     2011-11-13 12:11:10 +0000 (Sun, 13 Nov 2011)
Log Message:
-----------
Fix compilation on FreeBSD (SIGCLD is a non-posix alias for SIGCHLD). Thanks, Thierry Thomas

Modified Paths:
--------------
    trunk/rkward/rkward/rbackend/rkrbackend.cpp

Modified: trunk/rkward/rkward/rbackend/rkrbackend.cpp
===================================================================
--- trunk/rkward/rkward/rbackend/rkrbackend.cpp	2011-11-10 09:02:44 UTC (rev 4028)
+++ trunk/rkward/rkward/rbackend/rkrbackend.cpp	2011-11-13 12:11:10 UTC (rev 4029)
@@ -1099,18 +1099,18 @@
 	if (backend_was_forked) return;
 	backend_was_forked = true;
 
 	// Block SIGCLD in the main thread from now on. I don't fully understand, why, but otherwise, these signals
 	// interrupt the select() call in the fork()ing code of library(parallel)
 	sigset_t new_set;
 	sigemptyset (&new_set);
-	sigaddset (&new_set, SIGCLD);
+	sigaddset (&new_set, SIGCHLD);
 	pthread_sigmask (SIG_BLOCK, &new_set, NULL);
 
 //	This was used to show a warning message. Unfortunately, however, forks also occur on every popen (i.e. in system(..., intern=TRUE).
 //	RKRBackend::this_pointer->handlePlainGenericRequest (QStringList ("forkNotification"), false);
 	RK_DO (qDebug ("Backend process forked (for the first time, this session)"), RBACKEND, DL_WARNING);
 //	NOTE: perhaps we can heuristically differentiate from popen by checking sys.calls() for something with "fork" in it. 
 //	esp., in case we discover adverse side-effects of blocking SIGCLD, we should attempt this
 }
 
 void completeForkChild () {
@@ -1099,18 +1099,18 @@
 	backend_was_forked = true;
 
-	// Block SIGCLD in the main thread from now on. I don't fully understand, why, but otherwise, these signals
+	// Block SIGCHLD in the main thread from now on. I don't fully understand, why, but otherwise, these signals
 	// interrupt the select() call in the fork()ing code of library(parallel)
 	sigset_t new_set;
@@ -1099,18 +1099,18 @@
 	RK_DO (qDebug ("Backend process forked (for the first time, this session)"), RBACKEND, DL_WARNING);
 //	NOTE: perhaps we can heuristically differentiate from popen by checking sys.calls() for something with "fork" in it. 
-//	esp., in case we discover adverse side-effects of blocking SIGCLD, we should attempt this
+//	esp., in case we discover adverse side-effects of blocking SIGCHLD, we should attempt this
 }
 

This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.





More information about the rkward-tracker mailing list